from django.shortcuts import render_to_response
from django.core.paginator import Paginator


def index_view(request):
    objects = ['foo'] * 100
    paginator = Paginator(objects, 2)

    page = paginator.page(request.GET.get('page', 1))
    return render_to_response('index.html', {'page': page, 'request': request})



from django import template

from django_rangepaginator.layout import calculate_pages
from six.moves.urllib.parse import parse_qs, urlencode, urlparse, urlunparse

register = template.Library()


@register.inclusion_tag('django_rangepaginator/bootstrap3.html')
def paginate(page=None, distance=2, request=None):
    paginator = page.paginator
    pages = calculate_pages(
        page.number, paginator.num_pages, distance=distance)

    result = []
    if request:
        parts = urlparse(request.get_full_path())
        params = parse_qs(parts.query)
        for page_num in pages:
            if not page_num:
                result.append((page_num, None))
            else:
                params['page'] = [str(page_num)]
                query = urlencode(params, doseq=True)
                url = urlunparse(parts[:4] + (query,) + parts[5:])
                result.append((page_num, url))
    else:
        for page_num in pages:
            url = '?%s' % urlencode({'page': str(page_num)})
            result.append((page_num, url))
    pages = result

    return {
        'current': page.number,
        'pages': pages,
        'paginator': paginator,
    }



def calculate_pages(current, total, distance=2):
    lower_bound = max(1, current - distance)
    upper_bound = min(total, current + distance)

    items = []
    if lower_bound > 1:
        items.append(1)

    if lower_bound > 3:
        items.append(None)
    elif lower_bound > 2:
        items.append(2)

    for item in range(lower_bound, upper_bound + 1):
        items.append(item)

    if upper_bound + 2 < total:
        items.append(None)
    elif upper_bound + 1 < total:
        items.append(total - 1)

    if upper_bound < total:
        items.append(total)

    return items
